# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	Interface to sendmail's access.db
Name:		perl-Sendmail-AccessDB
Version:	1.04
Release:	4.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/dist/Sendmail-AccessDB
Source0:	https://cpan.metacpan.org/authors/id/S/ST/STEPHANJ/Sendmail-AccessDB-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(BerkeleyDB)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(vars)
# Test Suite
BuildRequires:	libdb-devel
# sendmail is a build requirement because makemap is needed for the tests
BuildRequires:	sendmail
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

%description
This module is designed so that users of the Sendmail::Milter module (or
other Sendmail programmers) can ascertain if a user has elected to
whitelist themselves as a "spam friend" (where there should be no spam
filtering on mail to them) or, where spam-filtering is not the default,
but an option, where certain recipients have been labelled as "spam
haters".

%prep
%setup -q -n Sendmail-AccessDB-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Sendmail/
%{_mandir}/man3/Sendmail::AccessDB.3*

%changelog
* Thu Jul  6 2023 Paul Howarth <paul@city-fan.org> - 1.04-4
- Switch upstream from search.cpan.org to metacpan.org
- Use SPDX-format license tag
- Drop support for building with ancient db4 packages
- Use %%license unconditionally

* Fri Apr 13 2018 Paul Howarth <paul@city-fan.org> - 1.04-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Sep 23 2016 Paul Howarth <paul@city-fan.org> - 1.04-2
- BR: perl-generators where available
- Simplify find command using -delete

* Wed Dec 24 2014 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04
  - Removed the locked sub attributes because they seem to have no gain (no
    object access/modification is done)
  - Enhanced the POD
  - Enhanced the tests so they skip if /usr/sbin/makemap is not installed
    (might need to bundle a .db again)
  - Enhanced the lookup function so it correctly checks all variations of an
    email address
- Drop upstreamed lock patch
- Classify buildreqs by usage

* Fri Aug 29 2014 Paul Howarth <paul@city-fan.org> - 1.03-2
- Drop %%defattr, redundant since rpm 4.4
- Use %%license where possible

* Thu Aug 23 2012 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
  - More test cases
- This release by STEPHANJ → update source URL
- Update patch fixing deprecation warnings

* Tue Jun 26 2012 Paul Howarth <paul@city-fan.org> - 1.01-7
- Use libdb rather than db4 from EL-7 onwards
- BR: perl(Carp) and perl(Exporter)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Wed Jul  6 2011 Paul Howarth <paul@city-fan.org> - 1.01-6
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 1.01-5
- Support build with libdb (db5) in Fedora 14 onwards
- Add patch to remove deprecation warnings with perl 5.12 onwards

* Wed May 26 2010 Paul Howarth <paul@city-fan.org> - 1.01-4
- BR: db4-devel so that this package works as a reliable test case for #592209

* Fri May  7 2010 Paul Howarth <paul@city-fan.org> - 1.01-3
- Fix dist tag to work with RHEL6 Beta

* Fri Mar  5 2010 Paul Howarth <paul@city-fan.org> - 1.01-2
- Dist tag for Rawhide no longer needs special-casing
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation
- Note that builds with 4.8.0 <= db4 <= 4.8.26 require a hacked sendmail
  (see #556148)

* Wed Nov 11 2009 Paul Howarth <paul@city-fan.org> - 1.01-1
- Update to 1.01 (fix a permissions issue in t/03_functions.t)

* Thu Sep 24 2009 Paul Howarth <paul@city-fan.org> - 0.09-6
- Clarify license as GPL (version 1 or later), or Artistic (i.e. same as perl)
- Define RPM macros in global scope

* Wed Jun  6 2007 Paul Howarth <paul@city-fan.org> - 0.09-5
- Fix dist tag for Fedora 7 onwards
- Fix argument order for find with -depth
- Add buildreq perl(ExtUtils::MakeMaker)

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.09-4
- Fix distribution tags for development releases

* Wed Mar 22 2006 Paul Howarth <paul@city-fan.org> - 0.09-3
- Simplify distribution-detection code
- Don't define %%perl_vendorarch in noarch package
- Remove %%__perl_version macro, used only once
- Remove %%__perl_package macro, used only twice
- Don't use macros in build-time command paths, hardcode them instead
- Remove buildroot unconditionally in %%clean and %%install
- Own directory %%{perl_vendorlib}/Sendmail
- Don't set up compiler optimization flags in noarch package
- Use search.cpan.org URLs

* Wed May 25 2005 Paul Howarth <paul@city-fan.org> - 0.09-2
- Rewrite spec file in (mainly) Fedora Extras style
- Include full URL for source
- Fix URL
- Use MODULE_COMPAT dependency style and remove explicit perl dependency
- Remove MANIFEST from %%doc

* Tue May 04 2004 Paul Howarth <paul@city-fan.org> - 0.09-1
- Update to 0.09
- DB_File requirement replaced by BerkeleyDB
- No longer necessary to manually create test.db

* Thu Apr 15 2004 Paul Howarth <paul@city-fan.org> - 0.07-4
- Added explicit perl dependency to ensure that an RPM built on a
  system with an updated version of perl (and hence having files
  installed in a place that a non-updated system won't find them)
  will not install on the non-updated system. In such cases, just
  rebuild from the source RPM
- Changed distribution-identifying macros for greater portability
- Fixed detection of Red Hat Linux for perl-DB_File dependency

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 0.07-3
- DB_File built into Fedora perl RPM, so don't require it for
  Fedora builds

* Mon Feb 16 2004 Paul Howarth <paul@city-fan.org> - 0.07-2
- Unified spec file for Red Hat and Fedora Core
- Added (Build)Requires: perl-DB_File

* Fri Jan 16 2004 Paul Howarth <paul@city-fan.org> - 0.07.fc1
- Initial build
